@@ -16,11 +16,36 @@
 
 package javassist.compiler;
 
-import javassist.*;
-import javassist.bytecode.*;
-import javassist.compiler.ast.*;
-
 import java.util.ArrayList;
+import java.util.List;
+
+import javassist.ClassPool;
+import javassist.CtClass;
+import javassist.CtField;
+import javassist.CtMethod;
+import javassist.Modifier;
+import javassist.NotFoundException;
+import javassist.bytecode.AccessFlag;
+import javassist.bytecode.Bytecode;
+import javassist.bytecode.ClassFile;
+import javassist.bytecode.ConstPool;
+import javassist.bytecode.Descriptor;
+import javassist.bytecode.FieldInfo;
+import javassist.bytecode.MethodInfo;
+import javassist.bytecode.Opcode;
+import javassist.compiler.ast.ASTList;
+import javassist.compiler.ast.ASTree;
+import javassist.compiler.ast.ArrayInit;
+import javassist.compiler.ast.CallExpr;
+import javassist.compiler.ast.Declarator;
+import javassist.compiler.ast.Expr;
+import javassist.compiler.ast.Keyword;
+import javassist.compiler.ast.Member;
+import javassist.compiler.ast.MethodDecl;
+import javassist.compiler.ast.NewExpr;
+import javassist.compiler.ast.Pair;
+import javassist.compiler.ast.Stmnt;
+import javassist.compiler.ast.Symbol;
 
 /* Code generator methods depending on javassist.* classes.
  */
@@ -46,8 +71,7 @@ public class MemberCodeGen extends CodeGen {
         ClassFile cf = thisClass.getClassFile2();
         if (cf == null)
             return ClassFile.MAJOR_VERSION;     // JDK 1.3
-        else
-            return cf.getMajorVersion();
+        return cf.getMajorVersion();
     }
 
     /**
@@ -64,6 +88,7 @@ public class MemberCodeGen extends CodeGen {
     /**
      * Returns the JVM-internal representation of this class name.
      */
+    @Override
     protected String getThisName() {
         return MemberResolver.javaToJvmName(thisClass.getName());
     }
@@ -71,11 +96,13 @@ public class MemberCodeGen extends CodeGen {
     /**
      * Returns the JVM-internal representation of this super class name.
      */
+    @Override
     protected String getSuperName() throws CompileError {
         return MemberResolver.javaToJvmName(
                         MemberResolver.getSuperclass(thisClass).getName());
     }
 
+    @Override
     protected void insertDefaultSuperCall() throws CompileError {
         bytecode.addAload(0);
         bytecode.addInvokespecial(MemberResolver.getSuperclass(thisClass),
@@ -83,13 +110,13 @@ public class MemberCodeGen extends CodeGen {
     }
 
     static class JsrHook extends ReturnHook {
-        ArrayList jsrList;
+        List<int[]> jsrList;
         CodeGen cgen;
         int var;
 
         JsrHook(CodeGen gen) {
             super(gen);
-            jsrList = new ArrayList();
+            jsrList = new ArrayList<int[]>();
             cgen = gen;
             var = -1;
         }
@@ -109,6 +136,7 @@ public class MemberCodeGen extends CodeGen {
             b.addIndex(0);
         }
 
+        @Override
         protected boolean doit(Bytecode b, int opcode) {
             switch (opcode) {
             case Opcode.RETURN :
@@ -157,6 +185,7 @@ public class MemberCodeGen extends CodeGen {
             var = retTarget[1];
         }
 
+        @Override
         protected boolean doit(Bytecode b, int opcode) {
             switch (opcode) {
             case Opcode.RETURN :
@@ -186,6 +215,7 @@ public class MemberCodeGen extends CodeGen {
         }
     }
 
+    @Override
     protected void atTryStmnt(Stmnt st) throws CompileError {
         Bytecode bc = bytecode;
         Stmnt body = (Stmnt)st.getLeft();
@@ -194,7 +224,7 @@ public class MemberCodeGen extends CodeGen {
 
         ASTList catchList = (ASTList)st.getRight().getLeft();
         Stmnt finallyBlock = (Stmnt)st.getRight().getRight().getLeft();
-        ArrayList gotoList = new ArrayList(); 
+        List<Integer> gotoList = new ArrayList<Integer>();
 
         JsrHook jsrHook = null;
         if (finallyBlock != null)
@@ -209,7 +239,7 @@ public class MemberCodeGen extends CodeGen {
         boolean tryNotReturn = !hasReturned;
         if (tryNotReturn) {
             bc.addOpcode(Opcode.GOTO);
-            gotoList.add(new Integer(bc.currentPc()));
+            gotoList.add(bc.currentPc());
             bc.addIndex(0);   // correct later
         }
 
@@ -235,7 +265,7 @@ public class MemberCodeGen extends CodeGen {
 
             if (!hasReturned) {
                 bc.addOpcode(Opcode.GOTO);
-                gotoList.add(new Integer(bc.currentPc()));
+                gotoList.add(bc.currentPc());
                 bc.addIndex(0);   // correct later
                 tryNotReturn = true;
             }
@@ -270,13 +300,11 @@ public class MemberCodeGen extends CodeGen {
     /**
      * Adds a finally clause for earch return statement.
      */
-    private void addFinally(ArrayList returnList, Stmnt finallyBlock)
+    private void addFinally(List<int[]> returnList, Stmnt finallyBlock)
         throws CompileError
     {
         Bytecode bc = bytecode;
-        int n = returnList.size();
-        for (int i = 0; i < n; ++i) {
-            final int[] ret = (int[])returnList.get(i);
+        for (final int[] ret:returnList) {
             int pc = ret[0];
             bc.write16bit(pc, bc.currentPc() - pc + 1);
             ReturnHook hook = new JsrHook2(this, ret);
@@ -289,6 +317,7 @@ public class MemberCodeGen extends CodeGen {
         }
     }
 
+    @Override
     public void atNewExpr(NewExpr expr) throws CompileError {
         if (expr.isArray())
             atNewArrayExpr(expr);
@@ -408,11 +437,13 @@ public class MemberCodeGen extends CodeGen {
         throw new CompileError("bad new expression");
     }
 
+    @Override
     protected void atArrayVariableAssign(ArrayInit init, int varType,
                                          int varArray, String varClass) throws CompileError {
         atNewArrayExpr2(varType, null, varClass, init);
     }
 
+    @Override
     public void atArrayInit(ArrayInit init) throws CompileError {
         throw new CompileError("array initializer is not supported");
     }
@@ -446,6 +477,7 @@ public class MemberCodeGen extends CodeGen {
         bytecode.addMultiNewarray(desc, count);
     }
 
+    @Override
     public void atCallExpr(CallExpr expr) throws CompileError {
         String mname = null;
         CtClass targetClass = null;
@@ -472,8 +504,7 @@ public class MemberCodeGen extends CodeGen {
             targetClass = thisClass;
             if (inStaticMethod)
                 throw new CompileError("a constructor cannot be static");
-            else
-                bytecode.addAload(0);   // this
+            bytecode.addAload(0);   // this
 
             if (((Keyword)method).get() == SUPER)
                 targetClass = MemberResolver.getSuperclass(targetClass);
@@ -563,6 +594,7 @@ public class MemberCodeGen extends CodeGen {
             isStatic = true;
         }
 
+        @SuppressWarnings("unused")
         int stack = bytecode.getStackDepth();
 
         // generate code for evaluating arguments.
@@ -784,6 +816,7 @@ public class MemberCodeGen extends CodeGen {
         }
     }
 
+    @Override
     protected void atFieldAssign(Expr expr, int op, ASTree left,
                         ASTree right, boolean doDup) throws CompileError
     {
@@ -842,7 +875,7 @@ public class MemberCodeGen extends CodeGen {
                 bytecode.add(PUTFIELD);
                 bytecode.growStack(is2byte ? -3 : -2);
             }
-        
+
             bytecode.addIndex(fi);
         }
         else {
@@ -858,10 +891,12 @@ public class MemberCodeGen extends CodeGen {
 
     /* overwritten in JvstCodeGen.
      */
+    @Override
     public void atMember(Member mem) throws CompileError {
         atFieldRead(mem);
     }
 
+    @Override
     protected void atFieldRead(ASTree expr) throws CompileError
     {
         CtField f = fieldAccess(expr, true);
@@ -904,20 +939,18 @@ public class MemberCodeGen extends CodeGen {
                                      minfo.getDescriptor());
             return 0;
         }
-        else {
-            int fi = addFieldrefInfo(f, finfo);
-            if (isStatic) {
-                bytecode.add(GETSTATIC);
-                bytecode.growStack(is2byte ? 2 : 1);
-            }
-            else {
-                bytecode.add(GETFIELD);
-                bytecode.growStack(is2byte ? 1 : 0);
-            }
-
-            bytecode.addIndex(fi);
-            return fi;
+        int fi = addFieldrefInfo(f, finfo);
+        if (isStatic) {
+            bytecode.add(GETSTATIC);
+            bytecode.growStack(is2byte ? 2 : 1);
         }
+        else {
+            bytecode.add(GETFIELD);
+            bytecode.growStack(is2byte ? 1 : 0);
+        }
+
+        bytecode.addIndex(fi);
+        return fi;
     }
 
     /**
@@ -929,18 +962,15 @@ public class MemberCodeGen extends CodeGen {
         throws CompileError
     {
         if (AccessFlag.isPrivate(finfo.getAccessFlags())
-            && f.getDeclaringClass() != thisClass) {
-            CtClass declClass = f.getDeclaringClass(); 
+                && f.getDeclaringClass() != thisClass) {
+            CtClass declClass = f.getDeclaringClass();
             if (isEnclosing(declClass, thisClass)) {
                 AccessorMaker maker = declClass.getAccessorMaker();
                 if (maker != null)
                     return maker;
-                else
-                    throw new CompileError("fatal error.  bug?");
             }
-            else
-                throw new CompileError("Field " + f.getName() + " in "
-                                       + declClass.getName() + " is private.");
+            throw new CompileError("Field " + f.getName() + " in "
+                                   + declClass.getName() + " is private.");
         }
 
         return null;    // accessible field
@@ -983,6 +1013,7 @@ public class MemberCodeGen extends CodeGen {
         return cp.addFieldrefInfo(ci, name, type);
     }
 
+    @Override
     protected void atClassObject2(String cname) throws CompileError {
         if (getMajorVersion() < ClassFile.JAVA_5)
             super.atClassObject2(cname);
@@ -990,6 +1021,7 @@ public class MemberCodeGen extends CodeGen {
             bytecode.addLdc(bytecode.getConstPool().addClassInfo(cname));
     }
 
+    @Override
     protected void atFieldPlusPlus(int token, boolean isPost,
                                    ASTree oprand, Expr expr, boolean doDup)
         throws CompileError
@@ -1130,16 +1162,14 @@ public class MemberCodeGen extends CodeGen {
         ASTList list = md.getThrows();
         if (list == null)
             return null;
-        else {
-            int i = 0;
-            clist = new CtClass[list.length()];
-            while (list != null) {
-                clist[i++] = resolver.lookupClassByName((ASTList)list.head());
-                list = list.tail();
-            }
-
-            return clist;
+        int i = 0;
+        clist = new CtClass[list.length()];
+        while (list != null) {
+            clist[i++] = resolver.lookupClassByName((ASTList)list.head());
+            list = list.tail();
         }
+
+        return clist;
     }
 
     /* Converts a class name into a JVM-internal representation.
@@ -1147,6 +1177,7 @@ public class MemberCodeGen extends CodeGen {
      * It may also expand a simple class name to java.lang.*.
      * For example, this converts Object into java/lang/Object.
      */
+    @Override
     protected String resolveClassName(ASTList name) throws CompileError {
         return resolver.resolveClassName(name);
     }
@@ -1154,6 +1185,7 @@ public class MemberCodeGen extends CodeGen {
     /* Expands a simple class name to java.lang.*.
      * For example, this converts Object into java/lang/Object.
      */
+    @Override
     protected String resolveClassName(String jvmName) throws CompileError {
         return resolver.resolveJvmClassName(jvmName);
     }
