@@ -22,11 +22,16 @@ import javassist.compiler.CompileError;
  * Array initializer such as <code>{ 1, 2, 3 }</code>.
  */
 public class ArrayInit extends ASTList {
+    /** default serialVersionUID */
+    private static final long serialVersionUID = 1L;
+
     public ArrayInit(ASTree firstElement) {
         super(firstElement);
     }
 
+    @Override
     public void accept(Visitor v) throws CompileError { v.atArrayInit(this); }
 
+    @Override
     public String getTag() { return "array"; }
 }
