@@ -5,6 +5,7 @@ import javassist.bytecode.annotation.*;
 import javassist.expr.*;
 import test3.*;
 
+@SuppressWarnings({"rawtypes","unchecked","unused"})
 public class JvstTest3 extends JvstTestRoot {
     public JvstTest3(String name) {
          super(name);
@@ -852,7 +853,7 @@ public class JvstTest3 extends JvstTestRoot {
     {
         java.lang.reflect.Method m =
             target.getClass().getMethod(method, new Class[] { long.class, int.class });
-        Object res = m.invoke(target, new Object[] { new Long(arg1), new Integer(arg2)});
+        Object res = m.invoke(target, new Object[] { Long.valueOf(arg1), Integer.valueOf(arg2)});
         return ((Integer)res).intValue();
     }
 
@@ -861,7 +862,7 @@ public class JvstTest3 extends JvstTestRoot {
     {
         java.lang.reflect.Method m =
             target.getClass().getMethod(method, new Class[] { int.class, double.class });
-        Object res = m.invoke(target, new Object[] { new Integer(arg1), new Double(arg2)});
+        Object res = m.invoke(target, new Object[] { Integer.valueOf(arg1), Double.valueOf(arg2)});
         return ((Integer)res).intValue();
     }
 
@@ -870,7 +871,7 @@ public class JvstTest3 extends JvstTestRoot {
     {
         java.lang.reflect.Method m =
             target.getClass().getMethod(method, new Class[] { int.class, String.class, Object.class });
-        Object res = m.invoke(target, new Object[] { new Integer(arg1), arg2, arg3});
+        Object res = m.invoke(target, new Object[] { Integer.valueOf(arg1), arg2, arg3});
         return ((Integer)res).intValue();
     }
 
@@ -1107,7 +1108,7 @@ public class JvstTest3 extends JvstTestRoot {
         sb.append("}"); 
         ctc.addMethod(CtNewMethod.make(sb.toString(), ctc));
         ctc.debugWriteFile();
-        ctc.toClass().newInstance(); 
+        ctc.toClass().getConstructor().newInstance();
     }
 
     // JIRA-83
