@@ -3,14 +3,17 @@ package javassist;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.TypeVariable;
 
+import javassist.bytecode.AccessFlag;
 import javassist.bytecode.AnnotationsAttribute;
 import javassist.bytecode.AttributeInfo;
 import javassist.bytecode.ClassFile;
 import javassist.bytecode.ConstPool;
 import javassist.bytecode.InnerClassesAttribute;
 import javassist.expr.ExprEditor;
+import javassist.expr.Handler;
 import javassist.expr.MethodCall;
 
+@SuppressWarnings({"rawtypes","unchecked","unused"})
 public class JvstTest5 extends JvstTestRoot {
     public JvstTest5(String name) {
         super(name);
@@ -77,7 +80,7 @@ public class JvstTest5 extends JvstTestRoot {
     }
 
     public void testJIRA242() throws Exception {
-        Boolean ss = new Boolean(2 > 3);
+        Boolean ss = Boolean.valueOf(2 > 3);
         ClassPool cp = ClassPool.getDefault();
         CtClass cc = cp.get("test5.JIRA242$Hello");
         CtMethod m = cc.getDeclaredMethod("say");
@@ -219,7 +222,7 @@ public class JvstTest5 extends JvstTestRoot {
         System.out.println(src);
         badClass.addMethod(CtMethod.make(src, badClass));
         Class clazzz = badClass.toClass();
-        Object obj = clazzz.newInstance(); // <-- falls here
+        Object obj = clazzz.getConstructor().newInstance(); // <-- falls here
     }
 
     public void test83StackmapWithArrayType() throws Exception {
@@ -237,6 +240,13 @@ public class JvstTest5 extends JvstTestRoot {
         assertEquals(1, invoke(obj, "run"));
     }
 
+    public void testLoaderClassPath() throws Exception {
+        ClassPool cp = new ClassPool();
+        cp.appendClassPath(new LoaderClassPath(new Loader()));
+        assertNotNull(cp.get(Object.class.getName()));
+        assertNotNull(cp.get(this.getClass().getName()));
+    }
+
     public void testAddDefaultMethod() throws Exception {
         CtClass cc = sloader.makeInterface("test5.AddDefaultMethod");
         cc.addMethod(CtNewMethod.make("static int foo() { return 1; }", cc));
@@ -284,4 +294,126 @@ public class JvstTest5 extends JvstTestRoot {
         Object obj = make(cc.getName());
         assertEquals(3, invoke(obj, "run"));
     }
+
+    public void testInnerClassModifiers() throws Exception {
+        CtClass cc = sloader.get("test5.InnerModifier$NonStatic");
+        try {
+            cc.setModifiers(Modifier.PUBLIC | Modifier.STATIC);
+            fail();
+        }
+        catch (RuntimeException e) {
+            if (!e.getMessage().startsWith("cannot change "))
+                fail();
+        }
+
+        cc.setModifiers(Modifier.PUBLIC);
+        cc.writeFile();
+
+        assertEquals(Modifier.PUBLIC, cc.getModifiers());
+        InnerClassesAttribute ica = getInnerClassAttr(cc);
+        int i = ica.find("test5.InnerModifier$NonStatic");
+        assertTrue(i >= 0);
+        assertEquals(Modifier.PUBLIC, ica.accessFlags(i));
+
+        CtClass cc2 = sloader.get("test5.InnerModifier$Static");
+
+        InnerClassesAttribute ica3 = getInnerClassAttr(cc2);
+        int i3 = ica3.find("test5.InnerModifier$Static");
+        assertTrue(i3 >= 0);
+        assertEquals(AccessFlag.STATIC, ica3.accessFlags(i3));
+
+        cc2.setModifiers(Modifier.PROTECTED | Modifier.STATIC);
+        cc2.setModifiers(Modifier.PUBLIC);
+        cc2.writeFile();
+
+        assertEquals(Modifier.PUBLIC | Modifier.STATIC, cc2.getModifiers());
+        InnerClassesAttribute ica2 = getInnerClassAttr(cc2);
+        int i2 = ica2.find("test5.InnerModifier$Static");
+        assertTrue(i2 >= 0);
+        assertEquals(AccessFlag.PUBLIC | AccessFlag.STATIC, ica2.accessFlags(i2));
+
+        CtClass cc3 = cc.getDeclaringClass();
+        assertTrue(cc3.isModified());
+        cc3.writeFile();
+
+        InnerClassesAttribute ica4 = getInnerClassAttr(cc3);
+        int i4 = ica4.find("test5.InnerModifier$Static");
+        assertTrue(i4 >= 0);
+        assertEquals(AccessFlag.PUBLIC | AccessFlag.STATIC, ica4.accessFlags(i4));
+        int i5 = ica4.find("test5.InnerModifier$NonStatic");
+        assertTrue(i5 >= 0);
+        assertEquals(Modifier.PUBLIC, ica4.accessFlags(i5));
+    }
+
+    public void testInnerClassModifiers2() throws Exception {
+        CtClass cc = sloader.get("test5.InnerModifier2$Protected");
+        Class<?> ccc = Class.forName("test5.InnerModifier2$Protected");
+        assertEquals(cc.getModifiers(), ccc.getModifiers());
+        assertTrue(Modifier.isProtected(cc.getModifiers()));
+
+        cc = sloader.get("test5.InnerModifier2$Public");
+        ccc = Class.forName("test5.InnerModifier2$Public");
+        assertEquals(cc.getModifiers(), ccc.getModifiers());
+        assertTrue(Modifier.isPublic(cc.getModifiers()));
+
+        cc = sloader.get("test5.InnerModifier2$Private");
+        ccc = Class.forName("test5.InnerModifier2$Private");
+        assertEquals(cc.getModifiers(), ccc.getModifiers());
+        assertTrue(Modifier.isPrivate(cc.getModifiers()));
+
+        cc = sloader.get("test5.InnerModifier2$Package");
+        ccc = Class.forName("test5.InnerModifier2$Package");
+        assertEquals(cc.getModifiers(), ccc.getModifiers());
+        assertTrue(Modifier.isPackage(cc.getModifiers()));
+
+        cc = sloader.get("test5.InnerModifier2$ProtectedStatic");
+        ccc = Class.forName("test5.InnerModifier2$ProtectedStatic");
+        assertEquals(cc.getModifiers(), ccc.getModifiers());
+        assertTrue(Modifier.isProtected(cc.getModifiers()));
+        assertTrue(Modifier.isStatic(cc.getModifiers()));
+
+        cc = sloader.get("test5.InnerModifier2$PublicStatic");
+        ccc = Class.forName("test5.InnerModifier2$PublicStatic");
+        assertEquals(cc.getModifiers(), ccc.getModifiers());
+        assertTrue(Modifier.isPublic(cc.getModifiers()));
+        assertTrue(Modifier.isStatic(cc.getModifiers()));
+
+        cc = sloader.get("test5.InnerModifier2$PrivateStatic");
+        ccc = Class.forName("test5.InnerModifier2$PrivateStatic");
+        assertEquals(cc.getModifiers(), ccc.getModifiers());
+        assertTrue(Modifier.isPrivate(cc.getModifiers()));
+        assertTrue(Modifier.isStatic(cc.getModifiers()));
+
+        cc = sloader.get("test5.InnerModifier2$PackageStatic");
+        ccc = Class.forName("test5.InnerModifier2$PackageStatic");
+        assertEquals(cc.getModifiers(), ccc.getModifiers());
+        assertTrue(Modifier.isPackage(cc.getModifiers()));
+        assertTrue(Modifier.isStatic(cc.getModifiers()));
+    }
+
+    private InnerClassesAttribute getInnerClassAttr(CtClass cc) {
+        return (InnerClassesAttribute)cc.getClassFile2().getAttribute(InnerClassesAttribute.tag);
+    }
+
+    public void testVarArgsModifier() throws Exception {
+        CtClass cc = sloader.get("test5.VarArgsMethod");
+        assertTrue(Modifier.isVarArgs(cc.getDeclaredMethod("foo").getModifiers()));
+        assertFalse(Modifier.isVarArgs(cc.getDeclaredMethod("bar").getModifiers()));
+    }
+
+    public void testIssue155() throws Exception {
+        CtClass cc = sloader.get("test5.Issue155");
+        CtMethod testMethod = cc.getDeclaredMethod("foo");
+        testMethod.instrument(
+                new ExprEditor() {
+                    public void edit(Handler m)
+                            throws CannotCompileException {
+                        m.insertBefore("throw $1;");
+                    }
+                });
+
+        cc.writeFile();
+        Object obj = make(cc.getName());
+        assertEquals(1, invoke(obj, "test"));
+    }
 }
